==> nextcloud-26.0.9.tgz: nextcloud/apps/user_status/l10n/vi.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Trạng thái gần đây",
    "No recent status changes" : "Không có thay đổi trạng thái gần đây",
    "In a meeting" : "Trong một cuộc họp",
    "Commuting" : "Đang di chuyển",
    "Out sick" : "Bị ốm",
    "Vacationing" : "Đi nghỉ",
    "Working remotely" : "Làm việc từ xa",
    "User status" : "Trạng thái người dùng",
    "Clear status after" : "Xóa trạng thái sau",
    "Emoji for your status message" : "Biểu tượng cảm xúc cho thông báo trạng thái của bạn",
    "What is your status?" : "Trạng thái của bạn là gì?",
    "Predefined statuses" : "Trạng thái được xác định trước",
    "Previously set" : "Đã đặt trước đó",
    "Reset status" : "Thiết lập trạng thái",
    "Set status" : "Đặt trạng thái",
    "Online status" : "Trạng thái trực tuyến",
    "Status message" : "Thông báo trạng thái",
    "Your status was set automatically" : "Trạng thái của bạn đã được đặt tự động",
    "Clear status message" : "Xoá thông báo trạng thái",
    "Set status message" : "Đặt thông báo trạng thái",
    "Reset status to \"{icon} {message}\"" : "Đặt lại trạng thái thành \"{icon} {message}\"",
    "Reset status to \"{message}\"" : "Đặt lại trạng thái thành \"{message}\"",
    "Reset status to \"{icon}\"" : "Đặt lại trạng thái thành \"{icon}\"",
    "There was an error saving the status" : "Đã xảy ra lỗi khi lưu trạng thái",
    "There was an error clearing the status" : "Đã xảy ra lỗi khi xóa trạng thái",
    "There was an error reverting the status" : "Đã xảy ra lỗi khi hoàn nguyên trạng thái",
    "Don't clear" : "Không xoá",
    "Today" : "Hôm nay",
    "This week" : "Tuần này",
    "Online" : "Trực tuyến",
    "Away" : "Tạm vắng",
    "Do not disturb" : "Đừng làm phiền",
    "Invisible" : "Vô hình",
    "Offline" : "Ngoại tuyến",
    "There was an error saving the new status" : "Đã xảy ra lỗi khi lưu trạng thái mới",
    "30 minutes" : "30 phút",
    "1 hour" : "1 tiếng",
    "4 hours" : "4 tiếng",
    "Mute all notifications" : "Tắt tiếng tất cả thông báo",
    "Appear offline" : "Đang offline",
    "View profile" : "Xem hồ sơ"
},
"nplurals=1; plural=0;");

==> nextcloud-29.0.5.tgz: nextcloud/apps/user_status/l10n/vi.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Trạng thái gần đây",
    "No recent status changes" : "Không có thay đổi trạng thái gần đây",
    "In a meeting" : "Trong một cuộc họp",
    "Commuting" : "Đang di chuyển",
    "Out sick" : "Bị ốm",
    "Vacationing" : "Đi nghỉ",
    "Out of office" : "Không ở văn phòng",
    "Working remotely" : "Làm việc từ xa",
    "User status" : "Trạng thái người dùng",
    "Clear status after" : "Xóa trạng thái sau",
    "Emoji for your status message" : "Biểu tượng cảm xúc cho thông báo trạng thái của bạn",
    "What is your status?" : "Trạng thái của bạn là gì?",
    "Predefined statuses" : "Trạng thái được xác định trước",
    "Previously set" : "Đã đặt trước đó",
    "Reset status" : "Thiết lập trạng thái",
    "Set status" : "Đặt trạng thái",
    "Online status" : "Trạng thái trực tuyến",
    "Status message" : "Thông báo trạng thái",
    "Your status was set automatically" : "Trạng thái của bạn đã được đặt tự động",
    "Clear status message" : "Xoá thông báo trạng thái",
    "Set status message" : "Đặt thông báo trạng thái",
    "Reset status to \"{icon} {message}\"" : "Đặt lại trạng thái thành \"{icon} {message}\"",
    "Reset status to \"{message}\"" : "Đặt lại trạng thái thành \"{message}\"",
    "Reset status to \"{icon}\"" : "Đặt lại trạng thái thành \"{icon}\"",
    "There was an error saving the status" : "Đã xảy ra lỗi khi lưu trạng thái",
    "There was an error clearing the status" : "Đã xảy ra lỗi khi xóa trạng thái",
    "There was an error reverting the status" : "Đã xảy ra lỗi khi hoàn nguyên trạng thái",
    "Don't clear" : "Không xoá",
    "Today" : "Hôm nay",
    "This week" : "Tuần này",
    "Online" : "Trực tuyến",
    "Away" : "Tạm vắng",
    "Do not disturb" : "Đừng làm phiền",
    "Invisible" : "Vô hình",
    "Offline" : "Ngoại tuyến",
    "There was an error saving the new status" : "Đã xảy ra lỗi khi lưu trạng thái mới",
    "30 minutes" : "30 phút",
    "1 hour" : "1 tiếng",
    "4 hours" : "4 tiếng",
    "Mute all notifications" : "Tắt tiếng tất cả thông báo",
    "Appear offline" : "Đang offline"
},
"nplurals=1; plural=0;");
